@@ -28,9 +28,9 @@ from sklearn import preprocessing
 
 class mlosmodeling:
     def __init__(self): 
-        print("mlOS Model Deployment - Initialized...")
+        self._noneed=""
     def tst(self,v):
-        print("Testing_modeling_:"+v)
+        self.test="yes"
     def getdbset(self,_init):
         try:
             if(os.path.exists(_init["fn_ds_conf"])==True):
@@ -76,17 +76,13 @@ class mlosmodeling:
                 mname="model-" + key 
             fpmodel = os.path.join(wp,org,project,"models", gener,sid, key, mname )
             model=[]
-            print(model_ext)
-            print(fpmodel)
             if os.path.exists(fpmodel):
                 if (model_ext=="bin"): 
                     model= fasttext.load_model(fpmodel)
                 elif (model_ext=="h5"):
                     model = tf.keras.models.load_model(fpmodel)
                 elif (model_ext=="_noext_"):
-                    print("=======HERE MODEL========")
                     model = tf.keras.models.load_model(fpmodel)
-                    print(model)
                 else:
                     with open(fpmodel, 'rb') as infile:  
                         model = pickle.load(infile)
